"use client";
// Chakra Imports
import { Box, Button, Center, Flex, Icon, Image, Link, Menu, MenuButton, MenuItem, MenuList, Text, useColorMode, useColorModeValue } from "@chakra-ui/react";
import { signOut } from "next-auth/react";

// Custom Components
import { ItemContent } from "@/components/menu/ItemContent";
import { SearchBar } from "@/components/navbar/searchBar/SearchBar";
import { SidebarResponsive } from "@/components/sidebar/Sidebar";
// Assets
import navImage from "/public/img/layout/Navbar.png";
import { FaEthereum } from "react-icons/fa";
import { IoMdMoon, IoMdSunny } from "react-icons/io";
import routes from "routes";
import { useGeneral } from "@/contexts/GeneralContext";
export default function HeaderLinks(props: { secondary: boolean; onOpen: boolean | any; fixed: boolean | any }) {
  const { currentUser } = useGeneral();
  const { secondary } = props;
  const { colorMode, toggleColorMode } = useColorMode();
  const [firstLetter, lastLetter] = [currentUser?.first_name?.charAt(0), currentUser?.last_name?.split(" ").pop().charAt(0)];
  const appRoutes = routes(currentUser.roles[0]);


  // Chakra Color Mode
  const navbarIcon = useColorModeValue("gray.400", "white");
  let menuBg = useColorModeValue("white", "navy.800");
  const textColor = useColorModeValue("secondaryGray.900", "white");
  const textColorBrand = useColorModeValue("brand.700", "brand.400");
  const ethColor = useColorModeValue("gray.700", "white");
  const borderColor = useColorModeValue("#E6ECFA", "rgba(135, 140, 189, 0.3)");
  const ethBg = useColorModeValue("secondaryGray.300", "navy.900");
  const ethBox = useColorModeValue("white", "navy.800");
  const shadow = useColorModeValue("14px 17px 40px 4px rgba(112, 144, 176, 0.18)", "14px 17px 40px 4px rgba(112, 144, 176, 0.06)");
  const borderButton = useColorModeValue("secondaryGray.500", "whiteAlpha.200");

  return (
    <Flex w={{ sm: "100%", md: "auto" }} alignItems="center" flexDirection="row" bg={menuBg} flexWrap={secondary ? { base: "wrap", md: "nowrap" } : "unset"} p="10px" borderRadius="30px" boxShadow={shadow}>
      <Flex bg={ethBg} display={secondary ? "flex" : "none"} borderRadius="30px" ms="auto" p="6px" align="center" me="6px">
        <Flex align="center" justify="center" bg={ethBox} h="29px" w="29px" borderRadius="30px" me="7px">
          <Icon color={ethColor} w="9px" h="14px" as={FaEthereum} />
        </Flex>
        <Text w="max-content" color={ethColor} fontSize="sm" fontWeight="700" me="6px">
          1,924
          <Text as="span" display={{ base: "none", md: "unset" }}>
            {" "}
            ETH
          </Text>
        </Text>
      </Flex>
      <SidebarResponsive routes={appRoutes} />

      <Button
        variant="no-hover"
        bg="transparent"
        p="0px"
        minW="unset"
        minH="unset"
        h="18px"
        w="max-content"
        onClick={() => {
          toggleColorMode();
        }}>
        <Icon me="10px" h="18px" w="18px" color={navbarIcon} as={colorMode === "light" ? IoMdMoon : IoMdSunny} />
      </Button>
      <Menu>
        <MenuButton p="0px" style={{ position: "relative" }}>
          <Box _hover={{ cursor: "pointer" }} color="white" bg="#11047A" w="40px" h="40px" borderRadius={"50%"} />
          <Center top={0} left={0} position={"absolute"} w={"100%"} h={"100%"}>
            <Text fontSize={"xs"} textTransform="uppercase" fontWeight="bold" color={"white"}>
              {firstLetter}
              {lastLetter}
            </Text>
          </Center>
        </MenuButton>
        <MenuList boxShadow={shadow} p="0px" mt="10px" borderRadius="20px" bg={menuBg} border="none">
          <Flex w="100%" mb="0px">
            <Text ps="20px" pt="16px" pb="10px" w="100%" borderBottom="1px solid" borderColor={borderColor} fontSize="sm" fontWeight="700" color={textColor}>
              👋&nbsp; Hey, <Text as="span" textTransform="capitalize">{currentUser?.full_name}</Text>
            </Text>
          </Flex>
          <Flex flexDirection="column" p="10px">
            <MenuItem bg={menuBg} _hover={{ bg: "none" }} _focus={{ bg: "none" }} color="red.400" borderRadius="8px" px="14px">
              <Text fontSize="sm" onClick={() => signOut()}>
                Log out
              </Text>
            </MenuItem>
          </Flex>
        </MenuList>
      </Menu>
    </Flex>
  );
}
